.TH C_TERM L "Radiation Oncology, NCMH"
.UC 4
.SH NAME
c_term \- "crash-proof" datum-entry routines for curses(3x)
.SH SYNOPSIS
#include <curses.h>
.br
#include <c_term.h>
.br
.B cc
[ flags ] files
.B \-lc_term \-lcurses \-ltermcap
[ libraries ]
.SH DESCRIPTION
These routines look after datum-entry through stdscr for the basic datum
types.
An initial call to
.I init_term
initializes the curses package by calling
.I initscr, raw, and noecho,
and initializes 
.I c_term
by fetching the terminal's erase character.
In typical use, the calling program would paint a screen
and place the cursor at the beginning of a datum field
using 
.I curses(3x)
and would then call the appropriate 
.I c_term
routine to enter or edit that datum.
The field is highlighted using standout mode and the default value, if any,
is displayed.
The user may then enter a new value of the datum under strict field size
enforcement or accept the default.
Acceptance of the displayed value is indicated by a RETURN.
The default value can be retrieved by ^X.
The program can be aborted by a character which is defined at installation of
the library.
If ABORT_CHAR is not defined, no abort is possible.
When the value is accepted, the field is rewritten in normal mode and with the
new value of the datum, and the cursor is left at the end of the field.

Exceptions to the above are
.I get_bool
for which valid inputs are n, N, y, Y, SPACE, and RETURN, for
no, yes, toggle, and accept respectively,
and
.I pick_one
which understands ^ for previous value, SPACE for next value, and RETURN
for accept.

The user is still responsible for the
.I endwin()
before exiting.
.SH SEE ALSO
curses(3x)
.SH AUTHOR
.nf
George W. Sherouse
Radiation Oncology
North Carolina Memorial Hospital
University of North Carolina, Chapel Hill
.SH FUNCTIONS
.nf
Initialize curses and c_term.
	void init_term();

Get a floating point number.  Imagine %(field_width).(places)f
in a printf.
	float get_float(default, field_width, places);
	float default;
	int field_width;
	int places;

Get an integer.
	int get_int(default, field_width);
	int default;
	int field_width;

Get a boolean.
	int get_bool(default);
	int default;

Get a hospital number in the format 00-00-00.
	void get_hosp_num(hosp_num);
	char *hosp_num

Get a string.  String should be at least field_size + 1 long
to accomodate the appended null.  Null_ok is a boolean which
declares whether or not a string of length zero is acceptable.
	void get_string(string, field_size, null_ok);
	char *string;
	int field_size;
	int null_ok;

Pick one string from a list of strings.
	int pick_one(list, choice_count);
	char **list;
	int choice_count;

Print string centered on line.  Mode is a boolean which requests
standout mode if TRUE.
	void center(line, string, mode);
	int line;
	char *string;
	int mode;
.SH BUGS
Many sorts of stupidity are not checked for.
These include but are not limited to string longer than COLS in
.I center,
fractional part longer than field_size in
.I get_float,
and 0 or negative field_size anywhere.

.I Get_float
does not support scientific notation.
It also does not let you back up over the decimal point once it has placed
it.
This is no great hardship since you can always ^X to restart.

Standout mode as implemented in
.I curses(3x)
is not reliable.
Try it on a terminal with magic cookies.

Some of the code is a little ugly, having been hacked unmercifully through many
revisions.
In particular, this
.I curses
compatible version is actually a hacked subset of a version which
talks to
.I termcap(3x)
directly.
It does seem to work, though.
